@@ -7,6 +7,7 @@
 #' @template bounds
 #' @template sorted
 #' @template null.ok
+#' @template typed.missing
 #' @template checker
 #' @family basetypes
 #' @seealso \code{\link{asInteger}}
@@ -16,8 +17,8 @@
 #' testInteger(1L)
 #' testInteger(1.)
 #' testInteger(1:2, lower = 1, upper = 2, any.missing = FALSE)
-checkInteger = function(x, lower = -Inf, upper = Inf, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, sorted = FALSE, names = NULL, null.ok = FALSE) {
-  .Call(c_check_integer, x, lower, upper, any.missing, all.missing, len, min.len, max.len, unique, sorted, names, null.ok)
+checkInteger = function(x, lower = -Inf, upper = Inf, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, sorted = FALSE, names = NULL, typed.missing = FALSE, null.ok = FALSE) {
+  .Call(c_check_integer, x, lower, upper, any.missing, all.missing, len, min.len, max.len, unique, sorted, names, typed.missing, null.ok)
 }
 
 #' @export
