@@ -2,6 +2,10 @@
 #include "backports.h"
 
 Rboolean attribute_hidden all_missing_logical(SEXP x) {
+#if defined(R_VERSION) && R_VERSION >= R_Version(3, 6, 0)
+    if (LOGICAL_NO_NA(x))
+        return FALSE;
+#endif
     const int * xp = LOGICAL_RO(x);
     const int * const xe = xp + xlength(x);
     for (; xp != xe; xp++) {
