@@ -1,10 +1,10 @@
 #ifndef CHECKMATE_ALL_MISSING_H_
 #define CHECKMATE_ALL_MISSING_H_
 
-#define USE_RINTERNALS
 #include <R.h>
 #include <Rinternals.h>
 #include <R_ext/Visibility.h>
+#include <Rversion.h>
 
 Rboolean all_missing_logical(SEXP);
 Rboolean all_missing_integer(SEXP);
