@@ -1,11 +1,8 @@
 #include "any_infinite.h"
-
-static Rboolean any_infinite_double(SEXP x);
-static Rboolean any_infinite_complex(SEXP x);
-static Rboolean any_infinite_list(SEXP x);
+#include "backports.h"
 
 static Rboolean any_infinite_double(SEXP x) {
-    const double * xp = REAL(x);
+    const double * xp = REAL_RO(x);
     const double * const xe = xp + xlength(x);
     for (; xp != xe; xp++) {
         if (*xp == R_PosInf || *xp == R_NegInf)
@@ -15,7 +12,7 @@ static Rboolean any_infinite_double(SEXP x) {
 }
 
 static Rboolean any_infinite_complex(SEXP x) {
-    const Rcomplex * xp = COMPLEX(x);
+    const Rcomplex * xp = COMPLEX_RO(x);
     const Rcomplex * const xe = xp + xlength(x);
     for (; xp != xe; xp++) {
         if ((*xp).r == R_PosInf || (*xp).i == R_PosInf ||
@@ -43,6 +40,6 @@ Rboolean any_infinite(SEXP x) {
     return FALSE;
 }
 
-SEXP c_any_infinite(SEXP x) {
+SEXP attribute_hidden c_any_infinite(SEXP x) {
     return ScalarLogical(any_infinite(x));
 }
